@@ -80,7 +80,12 @@ class RedditContentObject(object):
 
     def __getattr__(self, attr):
         """Return the value of the `attr` attribute."""
-        if attr != '__setstate__' and not self._has_fetched:
+        # Because this method may perform web requests, there are certain
+        # attributes we must blacklist to prevent accidental requests:
+        # __members__, __methods__: Caused by `dir(obj)` in Python 2.
+        # __setstate__: Caused by Pickle deserialization.
+        blacklist = ('__members__', '__methods__', '__setstate__')
+        if attr not in blacklist and not self._has_fetched:
             self._has_fetched = self._populate(None, True)
             return getattr(self, attr)
         msg = '\'{0}\' has no attribute \'{1}\''.format(type(self), attr)
@@ -221,18 +226,22 @@ class Moderatable(RedditContentObject):
         return response
 
     @restrict_access(scope='modposts')
-    def distinguish(self, as_made_by='mod'):
+    def distinguish(self, as_made_by='mod', sticky=False):
         """Distinguish object as made by mod, admin or special.
 
         Distinguished objects have a different author color. With Reddit
         Enhancement Suite it is the background color that changes.
 
+        `sticky` argument only used for top-level Comments.
+
         :returns: The json response from the server.
 
         """
         url = self.reddit_session.config['distinguish']
         data = {'id': self.fullname,
                 'how': 'yes' if as_made_by == 'mod' else as_made_by}
+        if isinstance(self, Comment) and self.is_root:
+            data['sticky'] = sticky
         return self.reddit_session.request_json(url, data=data)
 
     @restrict_access(scope='modposts')
@@ -1229,6 +1238,20 @@ class Submission(Editable, Gildable, Hideable, Moderatable, Refreshable,
         """
         return self.subreddit.get_flair_choices(self.fullname, *args, **kwargs)
 
+    @restrict_access(scope='modposts')
+    def lock(self):
+        """Lock thread.
+
+        Requires that the currently authenticated user has the modposts oauth
+        scope or has user/password authentication as a mod of the subreddit.
+
+        :returns: The json response from the server.
+
+        """
+        url = self.reddit_session.config['lock']
+        data = {'id': self.fullname}
+        return self.reddit_session.request_json(url, data=data)
+
     def mark_as_nsfw(self, unmark_nsfw=False):
         """Mark as Not Safe For Work.
 
@@ -1385,6 +1408,20 @@ class Submission(Editable, Gildable, Hideable, Moderatable, Refreshable,
             data['num'] = 1
         return self.reddit_session.request_json(url, data=data)
 
+    @restrict_access(scope='modposts')
+    def unlock(self):
+        """Lock thread.
+
+        Requires that the currently authenticated user has the modposts oauth
+        scope or has user/password authentication as a mod of the subreddit.
+
+        :returns: The json response from the server.
+
+        """
+        url = self.reddit_session.config['unlock']
+        data = {'id': self.fullname}
+        return self.reddit_session.request_json(url, data=data)
+
     def unmark_as_nsfw(self):
         """Mark as Safe For Work.
 
